local({
## Compute
setwd("PATH/testdir")
})
local({
## Compute
setwd("PATH")
})
